Trace, Stream and IrisClient and their associated methods
are inspired by the functionality available in the python ObsPy package (http://obspy.org/).
getNetwork, getStation, getChannel, getAvailability, getUnavailability
getEvent to return a dataframe with columns named "latitude" and "longitude"
for consistency with all other web services
StationXML classes in favor of storing that information in slots of the Trace class.
Trace object slots @Sensor, @InstrumentSensitivity and @InputUnits
to store information as character, numeric and character instead of StationXML classes.
TraceHeader@quality slot now reflects the data quality returned in the miniSEED record
rather than the quality that was requested by getDataselect. (Requests with quality=B for "Best" typically return
quality=M.)
STALTA.Trace() method removes experimental algorithms and now uses C++ code from package
rollSeismic to calculate rolling means.
IrisClient now uses web services from http://service.iris.edu for the following methods:
getDataselect, getEvalresp, getEvent
Stream and Trace. PSD algorithms are now part of the PSD metric.
mergeTraces.Stream() method now accepts fillMethod="fillZero".
num_spikes metric based on seismicRoll::roll_hampel outlier detection.
correlation metric.
glitchMetrics.Rscript, correlationMetric.Rscript, pressureCorrelation.Rscript
trace@stats@processing slot for data processing information.
Stream methods: mergeTraces, plot
getGaps.Stream() method properly handles initial and final gaps.
IRIS DMC web services: http://service.iris.edu/
# Open a connection to IRIS DMC webservices
iris <- new("IrisClient", debug=TRUE)
starttime <- as.POSIXct("2010-02-27 06:45:00", tz="GMT")
endtime <- as.POSIXct("2010-02-27 07:45:00", tz="GMT")
# Get the seismic data
st <- getDataselect(iris,"IU","ANMO","00","BHZ",starttime,endtime)
# Extract the first trace, display the metadata and plot it
tr1 <- st@traces[[1]]
show(tr1@stats)
plot(tr1)
Run the code above in your browser using DataLab