"IrisClient"A class for making data and metadata requests from EarthScope web services.
site:Object of class "character":
this is the top level domain that the web services will be pointed to; defaults to "https://service.earthscope.org"
service_type:Object of class "character":
defaults to fdsnws; for data retrieval from the IRIS PH5 repository, set this to ph5ws;
debug:Object of class "logical":
when set to TRUE will cause any web service requestURL to be printed
useragent:Object of class "character":
client identification string
event_site:Object of class "character":
this is the top level domain that the event web service url will be pointed to; defaults to site or
if site="https://service.earthscope.org" or site="https://service.iris.edu",
defaults to "https://earthquake.usgs.gov"
dataselect_site:Object of class "character":
this is the top level domain that the dataselect web service url will be pointed to; defaults to site
station_site:Object of class "character":
this is the top level domain that the station web service url will be pointed to; defaults to site
availability_site:Object of class "character":
this is the top level domain that the availability web service url will be pointed to; defaults to site
retries:Object of class "numeric":
set the number of retries for API calls when receiving a server error response, must be 5 or fewer
Deprecated. Makes a channel request of the station web service and returns the result as a dataframe; see getAvailability
makes a channel request of the station web service and returns the result as a dataframe; see getChannel
makes a channel request of the irisws availability web service and returns the result as a dataframe; see getDataAvailability
makes a request of the dataselect web service and returns a Stream object; see getDataselect
makes a request of the distaz web service and returns a the information as a dataframe; see getDistaz
makes a request of the instrument response web service and returns the information as a dataframe; see getEvalresp
makes a request of the event web service and returns the information as a dataframe; getEvent
makes a network request of the station web service and returns the result as a dataframe; see getNetwork
calls the getDataselect method and returns a Stream object; see getSNCL
makes a station request of the station web service and returns the result as a dataframe; see getStation
makes a request of the traveltime web service and returns the information as a dataframe; see getTraveltime
Deprecated. Makes a channel request of the station web service and returns the result as a dataframe; see getUnavailability
Jonathan Callahan jonathan@mazamascience.com
if (FALSE) {
# Open a connection to EarthScope webservices
iris <- new("IrisClient", debug=TRUE)
starttime <- as.POSIXct("2012-01-24", tz="GMT")
endtime <- as.POSIXct("2012-01-25", tz="GMT")
# Get the waveform
st <- getDataselect(iris,"AK","PIN","","BHZ",starttime,endtime)
mean(st)
}
Run the code above in your browser using DataLab