McNamaraPSD(tr, loFreq=.005, hiFreq=10, alignFreq=0.1, binned=TRUE)Trace objectlist object with the following named elements:freq, spec, snclq, starttime, endtime
Elements freq and spec are numeric vectors while snclq, starttime
and endtime are single values.
PSD object
containing the (potentially binned) spectrum for that segment. See the psdList function for
automatic segmenting of longer Stream objects.The McNamara PSD algorithm is similar to MATLAB's pwelch() function and has the following steps:
When binned=TRUE, McNamara style binning is
turned on and a smoothed spectrum is returned that contains many fewer points than the full spectrum.
When these arguments are not specified, binning is automatically turned off and the full spectrum is returned.
Frequencies for binning are generated at 1/8 octave intervals aligned to alignFreq.
The power (dB) associated with each frequency bin is calculated by averaging over an entire octave
centered on that frequency.
Note: The spectra returned by McNamaraPSD() have not had instrument correction applied.
Use getEvalresp to get instrument correction values for specific frequencies.
McNamaraBins,
psdList