assignQuality: Assign a quality code to a 'Stream' or 'Trace'

assignQualityR Documentation

Assign a quality code to a Stream or Trace

Description

The assignQuality methods of Stream and Trace objects return like objects that modify the quality code in the @id slot.

Usage

assignQuality(x, quality)

Arguments

x

a Trace or Stream object

quality

quality code, one of "R", "D", "Q", "M"

Details

The returned object will have a modified @id slot, where the last character is replaced by quality.

Value

A new Trace or Stream object is returned.

Author(s)

Gillian Sharer gillian.sharer@earthscope.org


IRISSeismic documentation built on March 19, 2026, 9:07 a.m.