The getDistaz method obtains great circle distance data from
the IRIS DMC distaz web service.
getDistaz(obj, latitude, longitude, staLatitude, staLongitude)an IrisClient object
latitude of seismic event
longitude of seismic event
latitude of seismic station
longitude of seismic station
A dataframe with the following columns:
ellipsoid.semiMajorAxis, ellipsoid.flattening, ellipsoid.name, fromlat, fromlon, tolat, tolon, azimuth,backAzimuth, distance, distanceMeters
Where fromlat is the event latitude, fromlon is the event longitude, tolat is the station latitude, and tolon
is the station longitude. azimuth, backAzimuth, and distance are measured in degrees. distanceMeters is distance in meters.
ellipsoid.semiMajorAxis, ellipsoid.flattening, and ellipsoid.name refer to the World Geodetic System standard coordinate system version used to correct for ellipticity when converting to geocentric latitudes.
Only a single row is returned.
The distance-azimuth service will calculate the great-circle angular distance, azimuth, and back azimuth between two geographic coordinate pairs. Azimuth and back azimuth are measured clockwise from North.
The IRIS DMC distaz webservice: