Learn R Programming

IRISSeismic (version 1.0.5)

getSNCL: Retrieve seismic data from IRIS DMC

Description

The getSNCL() method is a convenience wrapper for the getDataselect() method and returns a Stream object in which individual Traces have been sorted by start time.

Usage

getSNCL(obj, sncl, starttime, endtime, quality)

Arguments

obj
IrisClient object
sncl
character string with the SNCL code
starttime
POSIXct class specifying the starttime (GMT)
endtime
POSIXct class specifying the endtime (GMT)
quality
optional character string identifying the quality (default = "B")

Value

  • A new Stream object is returned.

Details

The SNCL argument should be ordered network-station-location channel, e.g. IU.ANMO.00.LHZ. This argument is split into component parts which are then used in a call to the getDataselect() method.

References

The IRIS DMC dataselect web service:

http://service.iris.edu/fdsnws/dataselect/1/

See Also

getDataselect, IrisClient-class