Learn R Programming

IRISSeismic (version 1.0.7-1)

hilbert: Hilbert of a seismic signal

Description

The hilbert method of Trace objects returns a Trace whose data have been replaced with the Hilbert transform of the seismic signal.

Usage

hilbert(x)

Arguments

x
a Trace object

Value

A Trace whose data have been replaced with the Hilbert transform of the seismic signal.

Details

Before calculating the Hilbert transform, the seismic trace is 'cleaned up' by removing the mean, the trend and by applying a cosine taper. See DDT for more details.

References

Seismic Attributes - A Review

Examples

Run this code
  ## Not run: 
# # Open a connection to IRIS DMC webservices
# iris <- new("IrisClient")
# 
# starttime <- as.POSIXct("2010-02-27 06:00:00", tz="GMT")
# endtime <- as.POSIXct("2010-02-27 09:00:00", tz="GMT")
# 
# # Get the waveform
# st <- getDataselect(iris,"IU","ANMO","00","BHZ",starttime,endtime)
# tr <- st@traces[[1]]
# 
# # Demean, detrend, cosine taper
# tr <- DDT(tr)
# 
# # Create Hilbert transform of the trace
# trh <- hilbert(tr)
# 
# # Plot signal data and hilbert data
# plot(tr@data, type='l', col='gray80')
# points(trh@data, type='l', col='blue')
#   ## End(Not run)

Run the code above in your browser using DataLab