noiseModels function returns the New High Noise Model and New Low Noise Model
from the Peterson paper. Values are returned for the specific frequencies specified in
the freq argument.
noiseModels(freq)nhnm and nlnm containing the high and
low noise models, respectively.
Seismic Noise Analysis System Using Power Spectral Density Probability Density Functions (McNamara and Boaz 2005)
psdStatistics,