psdDF2NoiseMatrix function uses the snclq identifier associated with the
first PSD in the dataframe to obtain instrument correction information at the specified frequencies
from the getEvalresp web service. This correction is applied to every PSD in
the dataframe and the now corrected PSD values are returned as a matrix.psdDF2NoiseMatrix(DF)getPSDMeasurements method of IrisClient.matrix is returned with one row for each instrument-corrected PSD and one column for each frequency bin.psdList2NoiseMatrix except that the input object
is a dataframe of PSD values obtained from the MUSTANG Backend Storage System.McNamaraPSD,
psdList,
psdList2NoiseMatrix,
psdPlot,
psdStatistics