Learn R Programming

IRISSeismic (version 1.0.7-1)

psdPlot: Generate plots from a set of PSDs

Description

The psdPlot function is used to generate plots from the data in a psdList or psdDF dataframe.

Usage

psdPlot(PSDs, style, showNoiseModel, showMaxMin, showMode, showMean, ...)

Arguments

PSDs
either a list as returned by psdList or a dataframe of PSD values obtained from the BSS
style
character identifier of plot type: 'psd' plots PSD lines, 'pdf' plots the pdfMatrix
showNoiseModel
logical controlling plotting of noise model lines (default=TRUE)
showMaxMin
logical controlling plotting of PSD max and min lines (default=TRUE)
showMode
logical controlling plotting of PDF mode line (default=TRUE)
showMean
logical controlling plotting of PSD mean line (default=FALSE)
...
arguments to be passed to plotting methods

Details

The psdPlot function creates visualizations for sets of PSDs. Plots generated with style='pdf' mimic the plots presented in the McNamara paper.

References

Seismic Noise Analysis System Using Power Spectral Density Probability Density Functions (McNamara and Boaz 2005)

See Also

McNamaraPSD, psdList, psdStatistics

Examples

Run this code
  ## Not run: 
# # Create a new IrisClient
# iris <- new("IrisClient", debug=TRUE)
# 
# # Get seismic data
# starttime <- as.POSIXct("2011-05-05", tz="GMT") # 2011.125
# endtime <- starttime + 1*24*3600
# st <- getDataselect(iris,"IU","GRFO","--","BHE",starttime,endtime)
# 
# # Generate power spectral density for each hour long segment
# psdList <- psdList(st)
# 
# # 'psd' line plot
# psdPlot(psdList,style='psd',type='l',col=adjustcolor('black',0.3))
# 
# # McNamara 'pdf' plot
# psdPlot(psdList,style='pdf')
#   ## End(Not run)

Run the code above in your browser using DataLab