Learn R Programming

IRISSeismic (version 1.0.5)

rotate2D: Rotate horiztonal components of a seismic signal

Description

The rotate2D() function rotates the two horizontal components of a seismic signal into Radial and Transverse compoents returned as a list of 2 Stream objects.

Usage

rotate2D(st1, st2, angle)

Arguments

st1
horizontal ('N' or '1') Stream from a channel set
st2
horizontal ('E' or '2') Stream from a channel set
angle
angle (degrees) of the rotation

Value

  • A list of two Stream objects stR and stT is returned.

Details

The rotation web service returns Radial and Transverse seismic Streams, generated by rotating st1 and st2 by angle degrees.

The rotation service uses the following transformation matrix to change the output vectors for 2-D horizontal transformations

$$M_{2D} = \left[ \begin{array}{cc} cos \alpha & sin \alpha \cr -sin \alpha & cos \alpha \end{array} \right]$$

$$\left[ \begin{array}{c} R \cr T \end{array} \right] = M_{2D} \left[ \begin{array}{c} N \cr E \end{array} \right]$$

where :

N and E represent data from the original (horizontal) orientations R and T represent the Radial and Transverse components. $\alpha$ is the azimuth angle measured clockwise from north

References

IRIS DMC rotation web service documentation:

http://service.iris.edu/irisws/rotation/docs/1/help/