unHistogram: Histogram to Vector
Description
If vec represents a set of binned counts of incrementing values (ascending)
return a vector of associated bin values with the proper count of each value. Intended
for internal use.
Usage
unHistogram(vec, startVal, incr)
Value
A vector of bin values with appropriate counts of each.
Arguments
- vec
a histogram vector or ordered set of binned counts
- startVal
the initial value of the first bin element
- incr
the increment rate of each subsequent bin value