Learn R Programming

IRISSeismic (version 1.0.5)

IRISSeismic-package: Classes and methods for seismic data analysis

Description

This package provides S4 classes for downloading and processing seismological data available from the IRIS Data Management Center (DMC) (http://www.iris.edu/dms/nodes/dmc/). Core classes Trace, Stream and IrisClient and their associated methods are inspired by the functionality available in the python ObsPy package (http://obspy.org/).

Arguments

Introduction

The "IRISSeismic-intro" vignette gives introductory examples on using the package.

History

version 1.0.4 -- name change to IRISSeismic
  • Name change required because 'seismic' was recently taken.
Using explicit references for 'utils' and 'stats' package functions as this is now required for CRAN.

itemize

  • NewrollSeismicpackage for fast rolling algorithms implemented in C++/Rcpp.

item

  • McNamaraBins() ignores bin #0 (~= DC)
  • McNamaraPSD() conversion to dB occurs after binning, not before
  • New hilbert() trace method.
  • Added rotate2D() function.
  • Added getSNCL() convenience wrapper for getDataselect() method.
  • Added getDistaz() method of IrisClient.
  • Added miniseed2Stream() and readMiniseedFile() functions.
  • Added getRotation() method of IrisClient.
  • Added spectral utility functions:
    • crossSpectrum()
    McNamaraBins()
  • All get~ methods that return dataframes now guarantee a default ordering of rows.
  • Use pracma::detrend() function in DDT.Trace().
  • Added "increment" parameter to STALTA.Trace().
  • Removed STALTA.Trace() algorithm "classic_LR2".
  • Fixed URL generation for getEvalresp() when location="".
  • Added NamaraPSD.Trace() method.
  • Added PSD/PDF utility functions:
    • noiseMatrix2PdfMatrix()
    noiseModels() psdDF2NoiseMatrix() psdList() psdList2NoiseMatrix() psdStatistics() psdPlot()
  • Updated version of getEvent to return a dataframe with columns named "latitude" and "longitude" for consistency with all other web services
  • Updated documentation and Rscripts to match the API changes in the conversion to FDSN web services.
  • Removal of all StationXML classes in favor of storing that information in slots of the Trace class.
  • Updates to Trace object slots @Sensor, @InstrumentSensitivity and @InputUnits to store information as character, numeric and character instead of StationXML classes.
  • The TraceHeader@quality slot now reflects the data quality returned in the miniSEED record rather than the quality that was requested by getDataselect. (Requests with quality=B for "Best" typically return quality=M.)
  • Improved STALTA.Trace() method removes experimental algorithms and now uses C++ code from package rollSeismic to calculate rolling means.
  • Updated IrisClient now uses web services from http://service.iris.edu for the following methods: getDataselect, getEvalresp, getEvent
  • Improved mergeTraces.Stream() method now accepts fillMethod="fillZero".
  • New num_spikes metric based on seismicRoll::roll_hampel outlier detection.
  • New correlation metric.
  • New scripts glitchMetrics.Rscript, correlationMetric.Rscript, pressureCorrelation.Rscript
  • New trace@stats@processing slot for data processing information.
  • New Stream methods: mergeTraces, plot
  • Improved getGaps.Stream() method properly handles initial and final gaps.
  • Improved MCR error messing.

References

ObsPy: http://obspy.org/

IRIS DMC web services: http://service.iris.edu/

See Also

IrisClient-class, Trace-class, Stream-class,

Examples

Run this code
# Open a connection to IRIS DMC webservices
iris <- new("IrisClient", debug=TRUE)

starttime <- as.POSIXct("2010-02-27 06:45:00", tz="GMT")
endtime <- as.POSIXct("2010-02-27 07:45:00", tz="GMT")

# Get the seismic data
st <- getDataselect(iris,"IU","ANMO","00","BHZ",starttime,endtime)

# Extract the first trace, display the metadata and plot it
tr1 <- st@traces[[1]]
show(tr1@stats)
plot(tr1)

Run the code above in your browser using DataLab