Learn R Programming

IRISSeismic (version 1.10.0)

assignQuality: Assign a quality code to a Stream or Trace

Description

The assignQuality methods of Stream and Trace objects return like objects that modify the quality code in the @id slot.

Usage

assignQuality(x, quality)

Value

A new Trace or Stream object is returned.

Arguments

x

a Trace or Stream object

quality

quality code, one of "R", "D", "Q", "M"

Author

Gillian Sharer gillian.sharer@earthscope.org

Details

The returned object will have a modified @id slot, where the last character is replaced by quality.