# Open a connection to IRIS DMC webservices
iris <- new("IrisClient")
# Date of Nisqually quake
starttime <- as.POSIXct("2001-02-28",tz="GMT")
endtime <- starttime + 2*24*3600
# Use getEvent web service to retrieve events in this time period
events <- getEvent(iris,starttime,endtime,6.0)
events
# Event #3 is the Nisqually quake in Washington State
e <- events[3,]
# Find all BHZ channels collecting data at the time of the quake and within
# 5 degrees of the quake epicenter
channels <- getAvailability(iris,"*","*","*","BHZ",starttime,endtime,
lat=e$latitude,long=e$longitude,maxradius=5)
channelsRun the code above in your browser using DataLab