This is the primary method for retrieving seismic data. Data requests are made
through the dataselect webservice and returned data are parsed using the
internal miniseed2Stream() function.
If the location argument contains an empty string to specify a 'blank' location
code, a location code of "--" will be used in the dataselect request URL.
(See dataselect documentation.)
If inclusiveEnd=FALSE, then getDataselect will subtract 0.000001
seconds from the endtime before passing the value to the dataselect
webservice. An endtime of, e.g., as.POSIXct("2016-01-03", tz="GMT") will
be passed into dataselect as end=2016-01-02T23:59:59.999999. A
data sample at time 2016-01-03T00:00:00 will not be returned unless
inclusiveEnd=TRUE.
Error returns from the webservice will stop evaluation and generate an error
message.
Sometimes the station webservice will return multiple records for the same SNCL,
each with a different scale or starttime. These represent different
epochs with potentially different metadata parameters for the SNCL and,
by default, will cause a 'Multiple epochs' error message to be generated.
Handling all possible metadata differences so that the data may be merged is
beyond the scope of this package. Instead, to avoid errors, users may specify
ignoreEpoch=TRUE in which case the very first SNCL-epoch encountered
will be used and all others will be discarded.
For access to restricted data, getDataselect will look for a system
environmental variable "IrisClient_passw" which should be a string in the form
"login:password". Alternatively, getDataselect will look for system
environmental variable "IrisClient_netrc" which should point to a .netrc
authentication file.