Learn R Programming

IRISSeismic (version 1.0.5)

getDistaz: Retrieve great circle distance information from IRIS DMC

Description

The getDistaz method obtains great circle distance data from the IRIS DMC distaz web service.

Usage

getDistaz(obj, latitude, longitude, staLatitude, staLongitude)

Arguments

obj
an IrisClient object
latitude
latitude of seismic event
longitude
longitude of seismic event
staLatitude
latitude of seismic station
staLongitude
longitude of seismic station

Value

  • A dataframe with the following columns:

    azimuth, backAzimuth, distance

    Only a single row is returned.

Details

The distance-azimuth service will calculate the great-circle angular distance, azimuth, and backazimuth between two geographic coordinate pairs. All results are reported in degrees, with azimuth and backazimuth measured clockwise from North.

References

The IRIS DMC distaz webservice:

http://service.iris.edu/irisws/distaz/1/

See Also

IrisClient-class