Learn R Programming

IRISSeismic (version 1.0.5)

getEvalresp: Retrieve instrument response information from IRIS DMC

Description

The getEvalresp method obtains instrument response data from the IRIS DMC evalresp webservice.

Usage

getEvalresp(obj, network, station, location, channel,
            time, minfreq, maxfreq, nfreq, units, output)

Arguments

obj
an IrisClient object
network
character string with the two letter seismic network code
station
character string with the station code
location
character string with the location code
channel
character string with the three letter channel code
time
POSIXct class specifying the time at which response is evaluated (GMT)
minfreq
optional minimum frequency at which response will be evaluated
maxfreq
optional maximum frequency at which response will be evaluated
nfreq
optional number of frequencies at which response will be evaluated
units
optional code specifying unit conversion
output
optional code specifying output type (default="fap")

Value

  • For output="fap", a dataframe with columns named:

    freq, amp, phase

    For output="cs", a dataframe with columns named:

    freq, real, imag

Details

The evalresp webservice responds to requests with data that can be used to remove instrument response from a seismic signal. Each of network, station or channel should contain a valid code without wildcards. The ascii string that is used for these values is simply passed through to evalresp.

If the location argument contains an empty string to specify a 'blank' location code, a location code of "--" will be used in the dataselect request URL. (See http://service.iris.edu/fdsnws/dataselect/1/{dataselect documentation}.)

The response from evalresp is converted into a dataframe with rows in order of increasing frequency.

References

The IRIS DMC evalresp webservice:

http://service.iris.edu/irisws/evalresp/1/

See Also

IrisClient-class,