getEvalresp method obtains instrument response data from
the IRIS DMC evalresp webservice.getEvalresp(obj, network, station, location, channel,
time, minfreq, maxfreq, nfreq, units, output)IrisClient objectoutput="fap", a dataframe with columns named:freq, amp, phase
For output="cs", a dataframe with columns named:
freq, real, imag
evalresp webservice responds to requests with data that can be used to
remove instrument response from a seismic signal.
Each of network, station or channel should contain
a valid code without wildcards. The ascii string that is used for
these values is simply passed through to evalresp.If the location argument contains an empty string to specify a 'blank' location code, a location
code of "--" will be used in the dataselect request URL.
(See
The response from evalresp is converted into a dataframe with rows in order of increasing frequency.
IrisClient-class,