| miniseed2Stream | R Documentation |
Stream objectThe miniseed2Stream function converts raw miniSEED bytes into a
Stream object.
miniseed2Stream(miniseed, url, requestedStarttime, requestedEndtime,
sensor, scale, scalefreq, scaleunits, latitude, longitude,
elevation, depth, azimuth, dip, removeZeroSampleTraces)
miniseed |
a vector of raw bytes read from a miniSEED file |
url |
optional, character source location (see getDataselect) |
requestedStarttime |
optional, |
requestedEndtime |
optional, |
sensor |
optional, character description of the Sensor type associated with this Station-Network-Channel-Location (SNCL) (see Trace) |
scale |
optional, character description of the InstrumentSensitivity associated with this SNCL (see Trace) |
scalefreq |
optional, numeric description of frequency at which the InstrumentSensitivity is correct, the SensitivityFrequency (see Trace) |
scaleunits |
optional, character description of the InputUnits associated with this SNCL (see Trace) |
latitude |
optional, numeric latitude associated with this SNCL (see Trace) |
longitude |
optional, numeric longitude associated with this SNCL (see Trace) |
elevation |
optional, numeric elevation associated with this SNCL (see Trace) |
depth |
optional, numeric depth associated with this SNCL (see Trace) |
azimuth |
optional, numeric channel azimuth associated with this SNCL (see Trace) |
dip |
optional, numeric channel dip associated with this SNCL (see Trace) |
removeZeroSampleTraces |
optional, logical determining whether traces with no sample values are removed (default = TRUE) |
This function takes raw bytes read in from a file or URL and converts them to a
Stream object. Metadata information is optional.
This function is primarily for internal use.
A Stream object.
Jonathan Callahan jonathan@mazamascience.com
readMiniseedFile
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.