Learn R Programming

IRISSeismic (version 1.0.5)

miniseed2Stream: Convert miniSEED bytes to Stream object

Description

The miniseed2Stream function converts raw miniSEED bytes into a Stream object.

Usage

miniseed2Stream(miniseed,url,requestedStarttime,requestedEndtime,
                sensor,scale,scaleunits)

Arguments

miniseed
a vector of raw bytes read from a miniSEED file
url
character source location (see getDataselect)
requestedStarttime
POSIXct time associated with the requested starttime (see getDataselect)
requestedEndtime
POSIXct time associated with the requested endtime (see getDataselect)
sensor
character description of the Sensor associated with this SNCL (see Trace)
scale
character description of the InstrumentSensitivity associated with this SNCL (see Trace)
scaleunits
character description of the InputUnits associated with this SNCL (see Trace)

Value

  • A Stream object.

Details

This function takes raw bytes read in from a file or URL and converts them to a Stream object. This function is primarily for internal use.

See Also

readMiniseedFile