Stream objects.rotate2D(st1, st2, angle)Stream from a channel setStream from a channel setStream objects stR and stT is returned.rotation web service returns Radial and Transverse seismic Streams, generated by
rotating st1 and st2 by angle degrees.The rotation service uses the following transformation matrix to change the output vectors for 2-D horizontal transformations
$$M_{2D} = \left[ \begin{array}{cc} cos \alpha & sin \alpha \cr -sin \alpha & cos \alpha \end{array} \right]$$
$$\left[ \begin{array}{c} R \cr T \end{array} \right] = M_{2D} \left[ \begin{array}{c} N \cr E \end{array} \right]$$
where :
N and E represent data from the original (horizontal) orientations R and T represent the Radial and Transverse components. $\alpha$ is the azimuth angle measured clockwise from north