## Not run:
# # Open a connection to IRIS DMC webservices
# iris <- new("IrisClient")
#
# starttime <- as.POSIXct("2002-04-20", tz="GMT")
# endtime <- as.POSIXct("2002-04-21", tz="GMT")
#
# # Get the waveform
# st <- getDataselect(iris,"US","OXF","","BHZ",starttime,endtime)
#
# # This Stream object consists of 5 Traces
# length(st@traces)
#
# # Plotting the third trace shows a small quake
# plot(st@traces[[3]])
#
# # We can slice out the hour that has the quake signal
# sliceStart <- as.POSIXct("2002-04-20 10:30:00", tz="GMT")
# sliceEnd <- as.POSIXct("2002-04-20 11:30:00", tz="GMT")
# stSlice <- slice(st, sliceStart, sliceEnd)
#
# # Now we only have one Trace of an hour duration
# length(stSlice@traces)
# stSlice@traces[[1]]@stats
# # And a better look at the quake signal
# plot(stSlice@traces[[1]])
# ## End(Not run)
Run the code above in your browser using DataLab